@@ -42,8 +42,8 @@ def init(username=None, password=None, **kwargs):
         user = env.get("USERNAME")
         pwd = env.get("PASSWORD")
 
-    assert user
-    assert pwd
+    # assert user
+    # assert pwd
 
     from hs_udata.utils.config import read_config, write_config
     # 获取系统配置
