@@ -19,7 +19,7 @@ def convert_date(dt, now=True):
 
     if isinstance(dt, str):
         from dateutil.parser import parse
-        return parse(dt).date().strftime("%Y-%m-%d")    #用parse进行格式转换，变成数据类型
+        return parse(dt).date().strftime("%Y%m%d")    #用parse进行格式转换，变成数据类型
 
     if hasattr(dt, "to_pydatetime"):                  #判断一个对象里面是否有"to_pydatetime"属性或者"to_pydatetime"方法
         return dt.to_pydatetime().date().strftime("%Y%m%d")
